@@ -37,6 +37,9 @@
  *
  * Does some caching in the hopes of achieving execute-at-most-once semantics.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <pthread.h>
 #include <reentrant.h>
 #include <sys/types.h>
